function speakPhoneMode()
  require "import"
  import "android.media.AudioManager"
  import "android.content.Context"

  context = activity or service
  audioManager = context.getSystemService(Context.AUDIO_SERVICE)

  function getPhoneMode()
    local mode = audioManager.getRingerMode()
    if mode == AudioManager.RINGER_MODE_SILENT then
      return "Silent"
    elseif mode == AudioManager.RINGER_MODE_VIBRATE then
      return "Vibrate"
    elseif mode == AudioManager.RINGER_MODE_NORMAL then
      return "Normal"
    else
      return "Unknown"
    end
  end

  local phoneMode = getPhoneMode()
  service.postSpeak(500, "Phone mode: " .. phoneMode)
end

require "import"
import "android.widget.SeekBar"
import "android.widget.LinearLayout"
import "android.widget.Button"
import "com.androlua.LuaDialog"
import "android.widget.TextView"
import "android.media.AudioManager"
import "android.content.Context"

context = activity or service
audioManager = context.getSystemService(Context.AUDIO_SERVICE)

function setVolume(streamType, progress)
  audioManager.setStreamVolume(streamType, progress, 0)
end

function setSoundMode(mode)
  currentMode = audioManager.getRingerMode()
  if mode == "vibrate" and currentMode ~= AudioManager.RINGER_MODE_VIBRATE then
    audioManager.setRingerMode(AudioManager.RINGER_MODE_VIBRATE)
  elseif mode == "ring" and currentMode ~= AudioManager.RINGER_MODE_NORMAL then
    audioManager.setRingerMode(AudioManager.RINGER_MODE_NORMAL)
  end
end

layout = {
  LinearLayout,
  layout_width = "match_parent",
  layout_height = "match_parent",
  orientation = 1,

  {
    LinearLayout,
    orientation = 0,
    layout_width = "match_parent",

    {
      TextView,
      id = "textview",
      text = "System audio",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      background = "#ff000000",
      textColor = "#f0f8ff",
      textSize = "25sp",
      gravity = "center",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    {
      SeekBar,
      id = "soundSeekBar",
      layout_width = "match_parent",
      layout_height = "80dp",
      contentDescription = "ring: ",
      background = "#ff000000",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    {
      SeekBar,
      id = "callSeekBar",
      layout_width = "match_parent",
      layout_height = "80dp",
      contentDescription = "call: ",
      background = "#ff000000",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    {
      SeekBar,
      id = "mediaSeekBar",
      layout_width = "match_parent",
      layout_height = "80dp",
      contentDescription = "media: ",
      background = "#ff000000",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    {
      SeekBar,
      id = "alarmSeekBar",
      layout_width = "match_parent",
      layout_height = "80dp",
      contentDescription = "alarm: ",
      background = "#ff000000",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    {
      SeekBar,
      id = "notificationSeekBar",
      layout_width = "match_parent",
      layout_height = "80dp",
      contentDescription = "notification: ",
      background = "#ff000000",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    {
      SeekBar,
      id = "accessibilitySeekBar",
      layout_width = "match_parent",
      layout_height = "80dp",
      contentDescription = "accessibility: ",
      background = "#ff000000",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    gravity = "center_horizontal",
    {
      Button,
      id = "soundModeButton",
      text = "Activate vibration mode",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      onClick = function(v)
        local buttonText = soundModeButton.getText()
        if buttonText == "Activate vibration mode" then
          setSoundMode("vibrate")
          soundModeButton.setText("Activate normal mode")
        elseif buttonText == "Activate normal mode" then
          setSoundMode("ring")
          service.playSoundTick()
          soundModeButton.setText("Activate vibration mode")
        end
      end,
      textSize = "30sp",
      background = "#0000ff",
    },
  },

  {
    LinearLayout,
    orientation = 1,
    layout_width = "match_parent",
    gravity = "center_horizontal",
    {
      Button,
      id = "backButton",
      text = "Back",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      onClick = function(v)
        dlg.dismiss()
      end,
      textSize = "30sp",
      background = "#ff0000",
    },
  },
}

function initializeSeekBar(seekBar, streamType)
  maxVolume = audioManager.getStreamMaxVolume(streamType)
  currentVolume = audioManager.getStreamVolume(streamType)

  seekBar.setMax(maxVolume)
  seekBar.setProgress(currentVolume)

  seekBar.setOnSeekBarChangeListener(luajava.createProxy("android.widget.SeekBar$OnSeekBarChangeListener", {
    onProgressChanged = function(seekBar, progress, fromUser)
      if fromUser then
        setVolume(streamType, progress)
      end
    end,
    onStartTrackingTouch = function(seekBar) end,
    onStopTrackingTouch = function(seekBar) end,
  }))
end

dlg = LuaDialog()
dlg.setView(loadlayout(layout))
dlg.show()

initializeSeekBar(soundSeekBar, AudioManager.STREAM_RING)
initializeSeekBar(callSeekBar, AudioManager.STREAM_VOICE_CALL)
initializeSeekBar(mediaSeekBar, AudioManager.STREAM_MUSIC)
initializeSeekBar(alarmSeekBar, AudioManager.STREAM_ALARM)
initializeSeekBar(notificationSeekBar, AudioManager.STREAM_NOTIFICATION)
initializeSeekBar(accessibilitySeekBar, AudioManager.STREAM_ACCESSIBILITY)